Module core_paths

Module core_paths 

Well-known core route paths.

These constants are the single source of truth for route paths used by both the core request dispatcher (handle_core_request) and framework-specific routers (e.g. Axum) so that path strings are never duplicated.

Constants

CHANGE_EMAIL
DELETE_USER
DELETE_USER_CALLBACK
ERROR
HEALTH
OK
OPENAPI_SPEC
UPDATE_USER