Modules
- account_
management - api_key
- email_
password - email_
verification - oauth
- organization
- passkey
- password_
management - plugins
- session_
management - two_
factor
Structs
- Account
Management Plugin - Account management plugin for listing and unlinking user accounts.
- ApiKey
Config - ApiKey
Plugin - API Key management plugin.
- Email
Password Plugin - Email and password authentication plugin
- Email
Verification Plugin - Email verification plugin for handling email verification flows
- OAuth
Plugin - Organization
Config - Configuration for the Organization plugin
- Organization
Plugin - Organization plugin for multi-tenancy support
- Passkey
Config - Passkey
Plugin - Passkey / WebAuthn authentication plugin.
- Password
Management Plugin - Password management plugin for password reset and change functionality
- Session
Management Plugin - Session management plugin for handling session operations
- TwoFactor
Config - TwoFactor
Plugin - Two-factor authentication plugin providing TOTP, OTP, and backup code flows.