SendChangeEmailConfirmation

Trait SendChangeEmailConfirmation 

pub trait SendChangeEmailConfirmation: Send + Sync {
    // Required method
    fn send<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
        &'life0 self,
        user: &'life1 UserInfo,
        new_email: &'life2 str,
        url: &'life3 str,
        token: &'life4 str,
    ) -> Pin<Box<dyn Future<Output = Result<(), AuthError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait,
             'life3: 'async_trait,
             'life4: 'async_trait,
             Self: 'async_trait;
}
Custom callback for sending change-email confirmation emails.

If set on ChangeEmailConfig, this callback is invoked instead of the default [EmailProvider]. This allows callers to customise the email subject, template, and delivery mechanism.

Required Methods

fn send<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>( &'life0 self, user: &'life1 UserInfo, new_email: &'life2 str, url: &'life3 str, token: &'life4 str, ) -> Pin<Box<dyn Future<Output = Result<(), AuthError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait, 'life3: 'async_trait, 'life4: 'async_trait, Self: 'async_trait,

Implementors